Package: perry
Type: Package
Title: Resampling-Based Prediction Error Estimation for Regression
        Models
Version: 0.3.1
Date: 2021-11-03
Depends: R (>= 2.14.1), ggplot2 (>= 0.9.2), parallel
Imports: stats, utils
Suggests: perryExamples, robustbase
Description: Tools that allow developers to write functions for prediction
    error estimation with minimal programming effort and assist users with
    model selection in regression problems.
License: GPL (>= 2)
LazyLoad: yes
Authors@R: person("Andreas", "Alfons",
    email = "alfons@ese.eur.nl",
    role = c("aut", "cre"))
Author: Andreas Alfons [aut, cre]
Maintainer: Andreas Alfons <alfons@ese.eur.nl>
Encoding: UTF-8
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2021-11-03 10:23:35 UTC; andreas
Repository: CRAN
Date/Publication: 2021-11-03 11:20:05 UTC
Built: R 4.4.0; ; 2024-04-29 21:44:40 UTC; unix
