# Generated by roxygen2: do not edit by hand

S3method("fits<-",perry)
S3method("fits<-",perrySelect)
S3method("peNames<-",perry)
S3method("peNames<-",perrySelect)
S3method(aggregate,perry)
S3method(aggregate,perrySelect)
S3method(aggregate,perryTuning)
S3method(autoplot,perry)
S3method(autoplot,perrySelect)
S3method(coef,perryTuning)
S3method(fits,perry)
S3method(fits,perrySelect)
S3method(fitted,perryTuning)
S3method(fortify,perry)
S3method(fortify,perrySelect)
S3method(fortify,perryTuning)
S3method(nfits,perry)
S3method(nfits,perrySelect)
S3method(npe,perry)
S3method(npe,perrySelect)
S3method(peNames,perry)
S3method(peNames,perrySelect)
S3method(perryFit,"function")
S3method(perryFit,call)
S3method(perryFit,default)
S3method(perryPlot,default)
S3method(perryPlot,perry)
S3method(perryPlot,perrySelect)
S3method(perryPlot,setupPerryPlot)
S3method(perrySplits,bootControl)
S3method(perrySplits,foldControl)
S3method(perrySplits,splitControl)
S3method(perryTuning,"function")
S3method(perryTuning,call)
S3method(plot,perry)
S3method(plot,perrySelect)
S3method(predict,perryTuning)
S3method(print,bootSamples)
S3method(print,cvFolds)
S3method(print,perry)
S3method(print,perrySelect)
S3method(print,perryTuning)
S3method(print,randomSplits)
S3method(print,summary.perry)
S3method(print,summary.perrySelect)
S3method(print,summary.perryTuning)
S3method(reperry,perry)
S3method(reperry,perrySelect)
S3method(residuals,perryTuning)
S3method(setupPerryPlot,perry)
S3method(setupPerryPlot,perrySelect)
S3method(setupPerryPlot,perryTuning)
S3method(subset,perry)
S3method(subset,perrySelect)
S3method(summary,perry)
S3method(summary,perrySelect)
S3method(summary,perryTuning)
export("fits<-")
export("peNames<-")
export(bootControl)
export(bootSamples)
export(cvFolds)
export(fits)
export(foldControl)
export(mape)
export(mspe)
export(nfits)
export(npe)
export(peNames)
export(perry)
export(perryFit)
export(perryPlot)
export(perryReshape)
export(perrySelect)
export(perrySplits)
export(perryTuning)
export(randomSplits)
export(reperry)
export(rmspe)
export(rtmspe)
export(setupPerryPlot)
export(splitControl)
export(tmspe)
import(ggplot2)
import(parallel)
import(stats)
importFrom(utils,getS3method)
